/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.chart;

/**
 * Represents a rectangle on a cartesian plane with integer coordinate.
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
public class IntRectangle {
    /**
     * x coordinate of the rectangle's top-left corner.
     */
    public int x = 0;

    /**
     * y coordinate of the rectangle's top-left corner.
     */
    public int y = 0;

    /**
     * The rectangle's width.
     */
    public int width = 1;

    /**
     * The rectangle's height.
     */
    public int height = 1;

    /**
     * Constructs a rectangle with vertexes in (0,0), (0,1), (1,0), (1,1).
     */
    public IntRectangle() {
        super();
    }

    /**
     * Copy constructor.
     * 
     * @param r
     *            the rectangle to be copied
     */
    public IntRectangle(IntRectangle r) {
        super();
        this.x = r.x;
        this.y = r.y;
        this.width = r.width;
        this.height = r.height;
    }

    /**
     * Standard constructor.
     * 
     * @param x
     *            coordinate of the rectangle's top-left corner
     * @param y
     *            coordinate of the rectangle's top-left corner
     * @param width
     *            the rectangle's width
     * @param height
     *            the rectangle's height
     */
    public IntRectangle(int x, int y, int width, int height) {
        super();
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
    }

    /**
     * Returns the x coordinate of the rectangle's top-left corner.
     * 
     * @return x
     */
    public int getX() {
        return this.x;
    }

    /**
     * Returns the y coordinate of the rectangle's top-left corner.
     * 
     * @return y
     */
    public int getY() {
        return this.y;
    }

    /**
     * Returns the rectangle's width.
     * 
     * @return the width
     */
    public int getWidth() {
        return this.width;
    }

    /**
     * Returns the rectangle's height.
     * 
     * @return the height
     */
    public int getHeight() {
        return this.height;
    }

    /**
     * Checks if the passed rectangle is identical to this one.
     * 
     * @param obj
     *            the rectangle to test
     * @return true if the two objects are identical
     */
    /*public boolean equals(Object obj) {
        IntRectangle r = (IntRectangle) obj;
        return r.getX() == this.x && r.getY() == this.y
                && r.getWidth() == this.width && r.getHeight() == this.height;
    }*/
}